@@ -20,8 +20,8 @@ class Break_align_engraver : public Engraver
   Protected_scm column_alist_;
 protected:
   virtual void do_removal_processing ();
-  virtual void acknowledge_element(Score_element_info i);
-  virtual void do_pre_move_processing ();
+  virtual void acknowledge_grob(Grob_info i);
+  virtual void stop_translation_timestep ();
   void add_column (SCM);
   
 public:
@@ -36,9 +36,9 @@ ADD_THIS_TRANSLATOR(Break_align_engraver);
 void
 Break_align_engraver::add_column (SCM smob)
 {
-  Score_element * e = unsmob_element (smob);
+  Grob * e = unsmob_element (smob);
   Break_align_interface::add_element (align_l_,e);
-  typeset_element (e);
+  typeset_grob (e);
 }
 
 void
@@ -48,7 +48,7 @@ Break_align_engraver::do_removal_processing ()
 }
 
 void
-Break_align_engraver::do_pre_move_processing ()
+Break_align_engraver::stop_translation_timestep ()
 {
   SCM order = get_property ("breakAlignOrder");
   for (; gh_pair_p (order); order = gh_cdr (order))
@@ -72,7 +72,7 @@ Break_align_engraver::do_pre_move_processing ()
 
   if (align_l_)
     {
-      typeset_element (align_l_);
+      typeset_grob (align_l_);
       align_l_ = 0;
     }
 }
@@ -85,19 +85,19 @@ Break_align_engraver::Break_align_engraver ()
 }
 
 void
-Break_align_engraver::acknowledge_element (Score_element_info inf)
+Break_align_engraver::acknowledge_grob (Grob_info inf)
 {
   if (Item * item_l = dynamic_cast <Item *> (inf.elem_l_))
     {
       if (item_l->empty_b (X_AXIS) || item_l->parent_l (X_AXIS))
 	return;
 
-      SCM bp=item_l->get_elt_property ("breakable");
+      SCM bp=item_l->get_grob_property ("breakable");
       bool breakable = (to_boolean (bp));
       if (!breakable)
 	return ;
 
-      SCM align_name = item_l->get_elt_property ("break-align-symbol");
+      SCM align_name = item_l->get_grob_property ("break-align-symbol");
       if (!gh_symbol_p (align_name))
 	return ;
 
@@ -105,7 +105,7 @@ Break_align_engraver::acknowledge_element (Score_element_info inf)
 	{
 	  align_l_ = new Item (get_property ("BreakAlignment"));
 	  Break_align_interface::set_interface (align_l_);
-	  announce_element (align_l_,0);
+	  announce_grob (align_l_,0);
 
 	  SCM edge_sym = ly_symbol2scm ("Left_edge_item");
 	  Item * edge = new Item (get_property ("LeftEdge"));
@@ -114,7 +114,7 @@ Break_align_engraver::acknowledge_element (Score_element_info inf)
 	    We must have left-edge in the middle.  Instrument-names
 	    are left to left-edge, so they don't enter the staff.
 	  */
-	  align_l_->set_elt_property ("self-alignment-X", edge->self_scm ());
+	  align_l_->set_grob_property ("self-alignment-X", edge->self_scm ());
 	  
 
 	  /*
@@ -123,11 +123,11 @@ Break_align_engraver::acknowledge_element (Score_element_info inf)
 
 	    TODO: switch off ignoring empty stuff?
 	  */
-	  edge->set_extent_callback (Score_element::point_dimension_callback_proc, X_AXIS);
+	  edge->set_extent_callback (Grob::point_dimension_callback_proc, X_AXIS);
 	  
-	  align_l_->set_elt_property ("self-alignment-X", edge->self_scm ());
+	  align_l_->set_grob_property ("self-alignment-X", edge->self_scm ());
 
-	  announce_element (edge, 0);
+	  announce_grob (edge, 0);
 	  column_alist_ = scm_assoc_set_x (column_alist_, edge_sym, edge->self_scm ());
 	}
 
@@ -137,7 +137,7 @@ Break_align_engraver::acknowledge_element (Score_element_info inf)
 
       if (s != SCM_BOOL_F)
 	{
-	  Score_element *e =  unsmob_element (gh_cdr(s));
+	  Grob *e =  unsmob_element (gh_cdr(s));
 	  group = dynamic_cast<Item*> (e);
 	}
       else
@@ -147,9 +147,9 @@ Break_align_engraver::acknowledge_element (Score_element_info inf)
 	  Axis_group_interface::set_interface (group);
 	  Axis_group_interface::set_axes (group, X_AXIS,X_AXIS);
 
-	  group->set_elt_property ("break-align-symbol", align_name);
+	  group->set_grob_property ("break-align-symbol", align_name);
 	  group->set_parent (align_l_, Y_AXIS);
-	  announce_element (group, 0);
+	  announce_grob (group, 0);
 	  column_alist_ = scm_assoc_set_x (column_alist_, align_name, group->self_scm ());
 
 	}
