@@ -26,7 +26,7 @@ MAKE_SCHEME_CALLBACK(Break_align_interface,before_line_breaking,1);
 SCM
 Break_align_interface::before_line_breaking (SCM smob)
 {
-  Score_element* me = unsmob_element (smob);
+  Grob* me = unsmob_element (smob);
   do_alignment (me);
   return SCM_UNSPECIFIED;
 }
@@ -35,14 +35,14 @@ MAKE_SCHEME_CALLBACK(Break_align_interface,alignment_callback,2);
 SCM
 Break_align_interface::alignment_callback (SCM element_smob, SCM axis)
 {
-  Score_element *me = unsmob_element (element_smob);
+  Grob *me = unsmob_element (element_smob);
   Axis a = (Axis) gh_scm2int (axis);
 
   assert (a == X_AXIS);
-  Score_element *par = me->parent_l (a);
-  if (par && !to_boolean (par->get_elt_property ("break-alignment-done")))\
+  Grob *par = me->parent_l (a);
+  if (par && !to_boolean (par->get_grob_property ("break-alignment-done")))\
     {
-      par->set_elt_property ("break-alignment-done", SCM_BOOL_T);
+      par->set_grob_property ("break-alignment-done", SCM_BOOL_T);
       Break_align_interface::do_alignment (par);
     }
     
@@ -53,7 +53,7 @@ MAKE_SCHEME_CALLBACK(Break_align_interface,self_align_callback,2);
 SCM
 Break_align_interface::self_align_callback (SCM element_smob, SCM axis)
 {
-  Score_element *me = unsmob_element (element_smob);
+  Grob *me = unsmob_element (element_smob);
   Axis a = (Axis) gh_scm2int (axis);
   assert (a == X_AXIS);
   
@@ -61,34 +61,34 @@ Break_align_interface::self_align_callback (SCM element_smob, SCM axis)
   Direction bsd = item->break_status_dir();
   if (bsd == LEFT)
     {
-      me->set_elt_property ("self-alignment-X", gh_int2scm (RIGHT));
+      me->set_grob_property ("self-alignment-X", gh_int2scm (RIGHT));
     }
 
   return Side_position::aligned_on_self (element_smob, axis);  
 }
 
 void
-Break_align_interface::add_element (Score_element*me, Score_element *toadd)
+Break_align_interface::add_element (Grob*me, Grob *toadd)
 {
   Axis_group_interface::add_element (me, toadd);
 }
 
 void
-Break_align_interface::do_alignment (Score_element *me)
+Break_align_interface::do_alignment (Grob *me)
 {
   Item * item = dynamic_cast<Item*> (me);
   Item *column = item->column_l ();
 
-  Link_array<Score_element> elems;
-  Link_array<Score_element> all_elems
-    = Pointer_group_interface__extract_elements (me, (Score_element*)0,
+  Link_array<Grob> elems;
+  Link_array<Grob> all_elems
+    = Pointer_group_interface__extract_elements (me, (Grob*)0,
 						 "elements");
   
   for (int i=0; i < all_elems.size(); i++) 
     {
       Interval y = all_elems[i]->extent(all_elems[i], X_AXIS);
       if (!y.empty_b())
-	elems.push (dynamic_cast<Score_element*> (all_elems[i]));
+	elems.push (dynamic_cast<Grob*> (all_elems[i]));
     }
   
   if (!elems.size ())
@@ -99,7 +99,7 @@ Break_align_interface::do_alignment (Score_element *me)
   SCM current_origin = ly_symbol2scm ("none");
   for (int i=0; i <= elems.size (); i++)
     {
-      Score_element *next_elt  = i < elems.size ()
+      Grob *next_elt  = i < elems.size ()
 	? elems[i]
 	: 0 ;
       
@@ -107,7 +107,7 @@ Break_align_interface::do_alignment (Score_element *me)
 
       if (next_elt)
 	{
-	  next_origin = next_elt->get_elt_property ("break-align-symbol");
+	  next_origin = next_elt->get_grob_property ("break-align-symbol");
 	  next_origin =
 	    gh_symbol_p (next_origin)? 
 	    next_origin : ly_symbol2scm ("none")
@@ -116,7 +116,7 @@ Break_align_interface::do_alignment (Score_element *me)
       else
 	next_origin = ly_symbol2scm ("begin-of-note");
 
-      SCM alist = me->get_elt_property ("space-alist");
+      SCM alist = me->get_grob_property ("space-alist");
       SCM e = scm_assoc (scm_listify (current_origin,
 				      next_origin,
 				      SCM_UNDEFINED), alist);
@@ -147,7 +147,7 @@ Break_align_interface::do_alignment (Score_element *me)
   symbol_list  = gh_cdr (scm_reverse (symbol_list));
   for (int i=0; i <elems.size()-1; i++)
     {
-      elems[i]->set_elt_property (gh_car  (symbol_list),
+      elems[i]->set_grob_property (gh_car  (symbol_list),
 				  scm_cons (gh_double2scm (0),
 					    gh_double2scm (dists[i+1])));
 
@@ -156,14 +156,14 @@ Break_align_interface::do_alignment (Score_element *me)
 
 
   // urg
-  SCM first_pair = elems[0]->get_elt_property ("minimum-space");
+  SCM first_pair = elems[0]->get_grob_property ("minimum-space");
   if (gh_pair_p (first_pair))
     first_pair = first_pair;
   else
     first_pair = gh_cons (gh_double2scm (0.0), gh_double2scm (0.0));
   
   scm_set_car_x (first_pair, gh_double2scm (-dists[0]));
-  elems[0]->set_elt_property ("minimum-space", first_pair);
+  elems[0]->set_grob_property ("minimum-space", first_pair);
 
 
   /*
@@ -204,18 +204,18 @@ Break_align_interface::do_alignment (Score_element *me)
 
     The pairs are in the format of an interval (ie. CAR <  CDR).
   */
-  column->set_elt_property ("extra-space",
+  column->set_grob_property ("extra-space",
 			    scm_cons (gh_double2scm (pre_space),
 				      gh_double2scm (spring_len)));
 
-  column->set_elt_property ("stretch-distance",
+  column->set_grob_property ("stretch-distance",
 			    gh_cons (gh_double2scm (-dists[0]),
 				     gh_double2scm (stretch_distance)));
 }
 
 
 void
-Break_align_interface::set_interface (Score_element*me)
+Break_align_interface::set_interface (Grob*me)
 {
   Align_interface::set_interface (me); 
   Align_interface::set_axis (me,X_AXIS);
