@@ -7,9 +7,11 @@
   
  */
 #include "context-specced-music.hh"
-
 Context_specced_music::Context_specced_music(Music *m)
   : Music_wrapper  (m)
 {
-  set_mus_property ("type", ly_symbol2scm ("context-specced-music"));
+  set_mus_property ("type",
+
+		    ly_symbol2scm ("context-specced-music"));
 }
+
