@@ -24,18 +24,18 @@ class Custos_engraver : public Engraver
 {
 public:
   Custos_engraver();
-  virtual void do_post_move_processing();
-  virtual void acknowledge_element(Score_element_info);
-  virtual void do_process_music ();
-  virtual void process_acknowledged ();
-  virtual void do_pre_move_processing ();
+  virtual void start_translation_timestep();
+  virtual void acknowledge_grob(Grob_info);
+  void deprecated_process_music ();
+  virtual void create_grobs ();
+  virtual void stop_translation_timestep ();
   virtual void do_removal_processing ();
   VIRTUAL_COPY_CONS(Translator);
 
 private:
   Item * create_custos();
   bool custos_permitted;
-  Link_array<Score_element> custos_arr_;
+  Link_array<Grob> custos_arr_;
   Array<Pitch> pitches_;
 };
 
@@ -46,7 +46,7 @@ Custos_engraver::Custos_engraver ()
 
 
 void
-Custos_engraver::do_pre_move_processing()
+Custos_engraver::stop_translation_timestep()
 {
   /*
     delay typeset until we're at the next moment, so we can silence custodes at the end of the piece.
@@ -54,11 +54,11 @@ Custos_engraver::do_pre_move_processing()
 }
 
 void
-Custos_engraver::do_post_move_processing ()
+Custos_engraver::start_translation_timestep ()
 {
   for (int i = custos_arr_.size (); i--;)
     {
-      typeset_element (custos_arr_[i]);
+      typeset_grob (custos_arr_[i]);
     }
   custos_arr_.clear ();
   pitches_.clear ();
@@ -71,14 +71,14 @@ Custos_engraver::do_post_move_processing ()
   TODO check if this works with forced bar lines?
  */
 void
-Custos_engraver::do_process_music ()
+Custos_engraver::deprecated_process_music ()
 {
   if (gh_string_p (get_property( "whichBar")))
     custos_permitted = true;
 }
 
 void
-Custos_engraver::acknowledge_element (Score_element_info info)
+Custos_engraver::acknowledge_grob (Grob_info info)
 {
   Item *item = dynamic_cast <Item *>(info.elem_l_);
   if (item)
@@ -104,15 +104,17 @@ Custos_engraver::acknowledge_element (Score_element_info info)
 }
 
 void
-Custos_engraver::process_acknowledged ()
+Custos_engraver::create_grobs ()
 {
+  deprecated_process_music ();
+
   if (custos_permitted)
     {
       for (int i = pitches_.size (); i--;)
 	{
 	  Item *c = create_custos ();
 	  
-	  c->set_elt_property ("staff-position",
+	  c->set_grob_property ("staff-position",
 			       gh_int2scm (pitches_[i].steps ()));
 	  
 	}
@@ -127,7 +129,7 @@ Custos_engraver::create_custos()
   SCM basicProperties = get_property ("Custos");
   Item* custos = new Item (basicProperties);
   
-  announce_element (custos, 0);
+  announce_grob (custos, 0);
   custos_arr_.push (custos);
   
   return custos;
@@ -139,7 +141,7 @@ Custos_engraver::do_removal_processing ()
   for (int i = custos_arr_.size (); i--;)
     {
       custos_arr_[i]->suicide ();
-      typeset_element (custos_arr_[i]);
+      typeset_grob (custos_arr_[i]);
     }
   custos_arr_.clear ();
 }
