@@ -15,15 +15,15 @@
 
 class Dot_column_engraver : public Engraver
 {
-  Score_element *dotcol_p_ ;
+  Grob *dotcol_p_ ;
   Link_array<Item> head_l_arr_;
 public:
   VIRTUAL_COPY_CONS(Translator);
   Dot_column_engraver();
   
 protected:
-  virtual void acknowledge_element (Score_element_info);
-  virtual void do_pre_move_processing ();  
+  virtual void acknowledge_grob (Grob_info);
+  virtual void stop_translation_timestep ();  
 };
 
 
@@ -33,20 +33,20 @@ Dot_column_engraver::Dot_column_engraver ()
 }
 
 void
-Dot_column_engraver::do_pre_move_processing ()
+Dot_column_engraver::stop_translation_timestep ()
 {
   if (dotcol_p_)
     {
-      typeset_element (dotcol_p_);
+      typeset_grob (dotcol_p_);
       dotcol_p_ =0;
     }
   head_l_arr_.clear ();
 }
 
 void
-Dot_column_engraver::acknowledge_element (Score_element_info info)
+Dot_column_engraver::acknowledge_grob (Grob_info info)
 {
-  Score_element *d = unsmob_element (info.elem_l_->get_elt_property ("dot"));
+  Grob *d = unsmob_element (info.elem_l_->get_grob_property ("dot"));
   if (d)
     {
       if (!dotcol_p_)
@@ -56,7 +56,7 @@ Dot_column_engraver::acknowledge_element (Score_element_info info)
 	  Dot_column::set_interface (dotcol_p_);
 	  Side_position::set_axis (dotcol_p_, X_AXIS);
 	  Side_position::set_direction (dotcol_p_, RIGHT);      
-	  announce_element (dotcol_p_, 0);
+	  announce_grob (dotcol_p_, 0);
 	}
 
       Dot_column::add_head (dotcol_p_, info.elem_l_);
