@@ -28,9 +28,10 @@ public:
   ~Dynamic_performer ();
 
 protected:
-  virtual bool do_try_music (Music* req_l);
-  virtual void do_process_music ();
-  virtual void do_pre_move_processing ();
+  virtual bool try_music (Music* req_l);
+  void deprecated_process_music ();
+  virtual void stop_translation_timestep ();
+  virtual void create_grobs ();
 
 private:
   Music* script_req_l_;
@@ -51,7 +52,7 @@ Dynamic_performer::~Dynamic_performer ()
 
 
 void
-Dynamic_performer::do_process_music ()
+Dynamic_performer::deprecated_process_music ()
 {
   if (script_req_l_)
     {
@@ -119,7 +120,13 @@ Dynamic_performer::do_process_music ()
 }
 
 void
-Dynamic_performer::do_pre_move_processing ()
+Dynamic_performer::create_grobs ()
+{
+  deprecated_process_music ();
+}
+
+void
+Dynamic_performer::stop_translation_timestep ()
 {
   if (audio_p_)
     {
@@ -129,7 +136,7 @@ Dynamic_performer::do_pre_move_processing ()
 }
 
 bool
-Dynamic_performer::do_try_music (Music* r)
+Dynamic_performer::try_music (Music* r)
 {
   if (!script_req_l_)
     {
