@@ -28,8 +28,8 @@
   then.  */
 class Extender_engraver : public Engraver
 {
-  Score_element *last_lyric_l_;
-  Score_element *current_lyric_l_;
+  Grob *last_lyric_l_;
+  Grob *current_lyric_l_;
   Extender_req* req_l_;
   Spanner* extender_p_;
 public:
@@ -37,12 +37,13 @@ public:
   VIRTUAL_COPY_CONS (Translator);
 
 protected:
-  virtual void acknowledge_element (Score_element_info);
+  virtual void acknowledge_grob (Grob_info);
   virtual void do_removal_processing();
-  virtual void do_process_music();
-  virtual bool do_try_music (Music*);
-  virtual void do_pre_move_processing();
-  virtual void do_post_move_processing ();
+  void deprecated_process_music();
+  virtual bool try_music (Music*);
+  virtual void stop_translation_timestep();
+  virtual void start_translation_timestep ();
+  virtual void create_grobs ();
 private:
 
 };
@@ -59,7 +60,7 @@ Extender_engraver::Extender_engraver ()
 }
 
 void
-Extender_engraver::acknowledge_element (Score_element_info i)
+Extender_engraver::acknowledge_grob (Grob_info i)
 {
   // -> text_item
   if (i.elem_l_->has_interface (ly_symbol2scm("text-item-interface")))
@@ -77,7 +78,7 @@ Extender_engraver::acknowledge_element (Score_element_info i)
 
 
 bool
-Extender_engraver::do_try_music (Music* r)
+Extender_engraver::try_music (Music* r)
 {
   if (Extender_req* p = dynamic_cast <Extender_req *> (r))
     {
@@ -101,9 +102,15 @@ Extender_engraver::do_removal_processing ()
 }
 
 void
-Extender_engraver::do_process_music ()
+Extender_engraver::create_grobs ()
 {
-  if (req_l_)
+  deprecated_process_music ();
+}
+
+void
+Extender_engraver::deprecated_process_music ()
+{
+  if (req_l_ && ! extender_p_)
     {
       if (!last_lyric_l_)
 	{
@@ -115,17 +122,17 @@ Extender_engraver::do_process_music ()
 
 
       Lyric_extender (extender_p_).set_textitem  (LEFT, last_lyric_l_);
-      announce_element (extender_p_, req_l_);
+      announce_grob (extender_p_, req_l_);
     }
 }
 
 
 void
-Extender_engraver::do_pre_move_processing ()
+Extender_engraver::stop_translation_timestep ()
 {
   if (extender_p_)
     {
-      typeset_element (extender_p_);
+      typeset_grob (extender_p_);
       extender_p_ = 0;
     }
 
@@ -137,7 +144,7 @@ Extender_engraver::do_pre_move_processing ()
 }
 
 void
-Extender_engraver::do_post_move_processing ()
+Extender_engraver::start_translation_timestep ()
 {
   req_l_ = 0;
 }
