@@ -3,12 +3,12 @@
 
 // thanks to GDBs wonderful casting abilities, we need these:
 Item*
-to_item (Score_element* g)
+to_item (Grob* g)
 {
   return dynamic_cast<Item*>(g);
 }
 Spanner*
-to_spanner (Score_element*g)
+to_spanner (Grob*g)
 {
   return dynamic_cast<Spanner*>(g);
 }
