@@ -17,22 +17,22 @@ MAKE_SCHEME_CALLBACK(Grace_align_item,before_line_breaking,1);
 SCM
 Grace_align_item::before_line_breaking (SCM smob)
 {
-  Score_element*me = unsmob_element (smob);
+  Grob*me = unsmob_element (smob);
 
-  SCM space = me->get_elt_property ("horizontal-space");
-  me->set_elt_property ("threshold",
+  SCM space = me->get_grob_property ("horizontal-space");
+  me->set_grob_property ("threshold",
 			gh_cons (space,
 				 gh_double2scm (infinity_f)));
-  dynamic_cast<Item*>(me)->column_l ()->set_elt_property ("contains-grace", SCM_BOOL_T);
+  dynamic_cast<Item*>(me)->column_l ()->set_grob_property ("contains-grace", SCM_BOOL_T);
 
   return SCM_UNSPECIFIED;
 }
 
 void
-Grace_align_item::set_interface (Score_element*me)
+Grace_align_item::set_interface (Grob*me)
 {
   me->set_interface (ly_symbol2scm ("grace-align-interface"));
-  me->set_elt_property ("stacking-dir", gh_int2scm (RIGHT));
+  me->set_grob_property ("stacking-dir", gh_int2scm (RIGHT));
   Align_interface::set_interface(me);
   Align_interface::set_axis (me,X_AXIS);
 }
@@ -40,7 +40,7 @@ Grace_align_item::set_interface (Score_element*me)
 
 
 bool
-Grace_align_item::has_interface (Score_element*m)
+Grace_align_item::has_interface (Grob*m)
 {
   return m&& m->has_interface (ly_symbol2scm ("grace-align-interface"));
 }
