@@ -8,6 +8,7 @@
  */
 
 #include "grace-music.hh"
+#include "grace-iterator.hh"
 
 void
 Grace_music::compress (Moment)
@@ -24,5 +25,6 @@ Grace_music::length_mom () const
 Grace_music::Grace_music (Music *p)
   : Music_wrapper (p)
 {
-  set_mus_property ("type", ly_symbol2scm ("grace-music"));
+  set_mus_property ("type",
+		    Grace_iterator::constructor_cxx_function);
 }
