@@ -20,10 +20,10 @@ protected:
   Item * nobreak_malt_p_;
   Spanner * sep_span_p_;
   
-  virtual void acknowledge_element (Score_element_info);
+  virtual void acknowledge_grob (Grob_info);
   virtual void do_creation_processing ();
   virtual void do_removal_processing ();
-  virtual void do_pre_move_processing ();
+  virtual void stop_translation_timestep ();
 public:
   Separating_line_group_engraver ();
   VIRTUAL_COPY_CONS (Translator);
@@ -41,7 +41,7 @@ Separating_line_group_engraver::do_creation_processing ()
 {
   sep_span_p_ = new Spanner (get_property ("SeparatingGroupSpanner"));
   Separating_group_spanner::set_interface (sep_span_p_);
-  announce_element (sep_span_p_, 0);
+  announce_grob (sep_span_p_, 0);
   sep_span_p_->set_bound (LEFT, unsmob_element (get_property ("currentCommandColumn")));
 }
 
@@ -49,12 +49,12 @@ void
 Separating_line_group_engraver::do_removal_processing ()
 {
   sep_span_p_->set_bound (RIGHT, unsmob_element (get_property ("currentCommandColumn")));
-  typeset_element (sep_span_p_);
+  typeset_grob (sep_span_p_);
   sep_span_p_ =0;
 }
 
 void
-Separating_line_group_engraver::acknowledge_element (Score_element_info i)
+Separating_line_group_engraver::acknowledge_grob (Grob_info i)
 {
   Item * it = dynamic_cast <Item *> (i.elem_l_);
   if (it && !it->parent_l (X_AXIS))
@@ -69,27 +69,27 @@ Separating_line_group_engraver::acknowledge_element (Score_element_info i)
 	    (get_property ("SeparationItem"));
 	  
 	  if (ib)
-	    p_ref_->set_elt_property ("breakable", SCM_BOOL_T);
-	  announce_element (p_ref_, 0);
+	    p_ref_->set_grob_property ("breakable", SCM_BOOL_T);
+	  announce_grob (p_ref_, 0);
 	}
       Separation_item::add_item (p_ref_,it);
     }
 }
 
 void
-Separating_line_group_engraver::do_pre_move_processing ()
+Separating_line_group_engraver::stop_translation_timestep ()
 {
   if (break_malt_p_)
     {
       Separating_group_spanner::add_spacing_unit (sep_span_p_, break_malt_p_);
       
-      typeset_element (break_malt_p_);
+      typeset_grob (break_malt_p_);
       break_malt_p_ =0;
     }
   if (nobreak_malt_p_)
     {
       Separating_group_spanner::add_spacing_unit (sep_span_p_, nobreak_malt_p_);
-      typeset_element (nobreak_malt_p_);
+      typeset_grob (nobreak_malt_p_);
       nobreak_malt_p_ =0;
     }
 }
