@@ -16,7 +16,7 @@
 #include "group-interface.hh"
 
 void
-Side_position::add_support (Score_element*me, Score_element*e)
+Side_position::add_support (Grob*me, Grob*e)
 {
   Pointer_group_interface::add_element (me, "side-support-elements",e);
 }
@@ -24,21 +24,21 @@ Side_position::add_support (Score_element*me, Score_element*e)
 
 
 Direction
-Side_position::get_direction (Score_element*me)
+Side_position::get_direction (Grob*me)
 {
-  SCM d = me->get_elt_property ("direction");
+  SCM d = me->get_grob_property ("direction");
   if (isdir_b (d))
     return to_dir (d) ? to_dir (d) : DOWN;
 
   Direction relative_dir = UP;
-  SCM reldir = me->get_elt_property ("side-relative-direction");	// should use a lambda.
+  SCM reldir = me->get_grob_property ("side-relative-direction");	// should use a lambda.
   if (isdir_b (reldir))
     {
       relative_dir = to_dir (reldir);
     }
   
-  SCM other_elt = me->get_elt_property ("direction-source");
-  Score_element * e = unsmob_element(other_elt);
+  SCM other_elt = me->get_grob_property ("direction-source");
+  Grob * e = unsmob_element(other_elt);
   if (e)
     {
       return (Direction)(relative_dir * Side_position::get_direction (e));
@@ -55,14 +55,14 @@ MAKE_SCHEME_CALLBACK(Side_position,side_position,2);
 SCM
 Side_position::side_position (SCM element_smob, SCM axis)
 {
-  Score_element *me = unsmob_element (element_smob);
+  Grob *me = unsmob_element (element_smob);
   Axis a = (Axis) gh_scm2int (axis);
 
-  Score_element *common = me->parent_l (a);
-  SCM support = me->get_elt_property ("side-support-elements");
+  Grob *common = me->parent_l (a);
+  SCM support = me->get_grob_property ("side-support-elements");
   for (SCM s = support; s != SCM_EOL; s = gh_cdr (s))
     {
-      Score_element * e  = unsmob_element (gh_car (s));
+      Grob * e  = unsmob_element (gh_car (s));
       if (e)
 	common = common->common_refpoint (e, a);
     }
@@ -71,7 +71,7 @@ Side_position::side_position (SCM element_smob, SCM axis)
   for (SCM s = support; s != SCM_EOL; s = gh_cdr (s))
     {
 
-      Score_element * e  = unsmob_element ( gh_car (s));
+      Grob * e  = unsmob_element ( gh_car (s));
       if (e)
 	{
 	  dim.unite (e->extent (common, a));
@@ -86,10 +86,10 @@ Side_position::side_position (SCM element_smob, SCM axis)
   Direction dir = Side_position::get_direction (me);
     
   Real off =  me->parent_l (a)->relative_coordinate (common, a);
-  SCM minimum = me->remove_elt_property ("minimum-space");
+  SCM minimum = me->remove_grob_property ("minimum-space");
 
   Real total_off = dim[dir] + off;
-  SCM padding = me->remove_elt_property ("padding");
+  SCM padding = me->remove_grob_property ("padding");
   if (gh_number_p (padding))
     {
       total_off += gh_scm2double (padding) * dir;
@@ -111,13 +111,13 @@ MAKE_SCHEME_CALLBACK(Side_position,aligned_on_self,2);
 SCM
 Side_position::aligned_on_self (SCM element_smob, SCM axis)
 {
-  Score_element *me = unsmob_element (element_smob);
+  Grob *me = unsmob_element (element_smob);
   Axis a = (Axis) gh_scm2int (axis);
   String s ("self-alignment-");
 
   s +=  (a == X_AXIS) ? "X" : "Y";
 
-  SCM align (me->get_elt_property (s.ch_C()));
+  SCM align (me->get_grob_property (s.ch_C()));
   if (gh_number_p (align))
     {
       Interval ext(me->extent (me,a));
@@ -160,7 +160,7 @@ MAKE_SCHEME_CALLBACK(Side_position,quantised_position,2);
 SCM
 Side_position::quantised_position (SCM element_smob, SCM )
 {
-  Score_element *me = unsmob_element (element_smob);
+  Grob *me = unsmob_element (element_smob);
   
   
   Direction d = Side_position::get_direction (me);
@@ -190,7 +190,7 @@ MAKE_SCHEME_CALLBACK(Side_position,aligned_side,2);
 SCM
 Side_position::aligned_side (SCM element_smob, SCM axis)
 {
-  Score_element *me = unsmob_element (element_smob);
+  Grob *me = unsmob_element (element_smob);
   Axis a = (Axis) gh_scm2int (axis);
   
   Direction d = Side_position::get_direction (me);
@@ -202,7 +202,7 @@ Side_position::aligned_side (SCM element_smob, SCM axis)
     {
       o += - iv[-d];
 
-      SCM pad = me->get_elt_property ("padding");
+      SCM pad = me->get_grob_property ("padding");
       if (gh_number_p (pad))
 	o += d *gh_scm2double (pad) ; 
     }
@@ -216,18 +216,18 @@ MAKE_SCHEME_CALLBACK(Side_position,centered_on_parent,2);
 SCM
 Side_position::centered_on_parent (SCM element_smob, SCM axis)
 {
-  Score_element *me = unsmob_element (element_smob);
+  Grob *me = unsmob_element (element_smob);
   Axis a = (Axis) gh_scm2int (axis);
-  Score_element *him = me->parent_l (a);
+  Grob *him = me->parent_l (a);
 
   return gh_double2scm (him->extent (him,a).center ());  
 }
 
 
 void
-Side_position::add_staff_support (Score_element*me)
+Side_position::add_staff_support (Grob*me)
 {
-  Score_element* st = Staff_symbol_referencer::staff_symbol_l (me);
+  Grob* st = Staff_symbol_referencer::staff_symbol_l (me);
   if (st)
     {
       add_support (me,st);
@@ -235,7 +235,7 @@ Side_position::add_staff_support (Score_element*me)
 }
 
 void
-Side_position::set_axis (Score_element*me, Axis a)
+Side_position::set_axis (Grob*me, Axis a)
 {
   me->add_offset_callback (Side_position::aligned_side_proc, a);
 }
@@ -244,7 +244,7 @@ Side_position::set_axis (Score_element*me, Axis a)
 
 // ugh. doesn't cactch all variants. 
 Axis
-Side_position::get_axis (Score_element*me)
+Side_position::get_axis (Grob*me)
 {
   if (me->has_offset_callback_b (Side_position::aligned_side_proc, X_AXIS)
       || me->has_offset_callback_b (Side_position::aligned_side_proc , X_AXIS))
@@ -255,33 +255,33 @@ Side_position::get_axis (Score_element*me)
 }
 
 void
-Side_position::set_direction (Score_element*me, Direction d)
+Side_position::set_direction (Grob*me, Direction d)
 {
-  me->set_elt_property ("direction", gh_int2scm (d));
+  me->set_grob_property ("direction", gh_int2scm (d));
 }
 
 void
-Side_position::set_minimum_space (Score_element*me, Real m)
+Side_position::set_minimum_space (Grob*me, Real m)
 {
-  me->set_elt_property ("minimum-space", gh_double2scm (m));
+  me->set_grob_property ("minimum-space", gh_double2scm (m));
 }
 
 void
-Side_position::set_padding (Score_element*me, Real p)
+Side_position::set_padding (Grob*me, Real p)
 {
-  me->set_elt_property ("padding", gh_double2scm (p));
+  me->set_grob_property ("padding", gh_double2scm (p));
 }
 
 bool
-Side_position::has_interface (Score_element*me) 
+Side_position::has_interface (Grob*me) 
 {
   return me->has_interface (ly_symbol2scm ("side-position-interface"));
 }
 
 bool
-Side_position::supported_b (Score_element*me) 
+Side_position::supported_b (Grob*me) 
 {
-  SCM s = me->get_elt_property  ("side-support-elements"); 
+  SCM s = me->get_grob_property  ("side-support-elements"); 
   return gh_pair_p(s);
 }
 
