@@ -14,11 +14,11 @@
 #include "warn.hh"
 #include "axis-group-interface.hh"
 #include "group-interface.hh"
-#include "score-element.hh"
+#include "grob.hh"
 #include "bar.hh"
 
 void
-Span_bar::add_bar (Score_element*me, Score_element*b)
+Span_bar::add_bar (Grob*me, Grob*b)
 {
   Pointer_group_interface::add_element (me,"elements", b);
 
@@ -29,10 +29,10 @@ MAKE_SCHEME_CALLBACK(Span_bar,width_callback,2);
 SCM
 Span_bar::width_callback (SCM element_smob, SCM scm_axis)
 {
-  Score_element *se = unsmob_element (element_smob);
+  Grob *se = unsmob_element (element_smob);
   Axis a = (Axis) gh_scm2int (scm_axis);
   assert (a == X_AXIS);
-  String gl = ly_scm2string (se->get_elt_property ("glyph"));
+  String gl = ly_scm2string (se->get_grob_property ("glyph"));
 
   /*
     urg.
@@ -60,7 +60,7 @@ MAKE_SCHEME_CALLBACK(Span_bar,center_on_spanned_callback,2);
 SCM
 Span_bar::center_on_spanned_callback (SCM element_smob, SCM axis)
 {
-  Score_element *me = unsmob_element (element_smob);
+  Grob *me = unsmob_element (element_smob);
   Axis a = (Axis) gh_scm2int (axis);
   assert (a == Y_AXIS);
   Interval i (get_spanned_interval (me));
@@ -74,7 +74,7 @@ Span_bar::center_on_spanned_callback (SCM element_smob, SCM axis)
 }
 
 void
-Span_bar::evaluate_empty (Score_element*me)
+Span_bar::evaluate_empty (Grob*me)
 {
   /*
     TODO: filter all hara-kiried out of ELEMENS list, and then
@@ -82,19 +82,19 @@ Span_bar::evaluate_empty (Score_element*me)
     center_on_spanned_callback() as well.
     
    */
-  if (!gh_pair_p (me->get_elt_property ("elements")))
+  if (!gh_pair_p (me->get_grob_property ("elements")))
     {
       me->suicide ();
     }
 }
 
 void
-Span_bar::evaluate_glyph (Score_element*me)
+Span_bar::evaluate_glyph (Grob*me)
 {
-  SCM elts = me->get_elt_property ("elements");
-  Score_element * b = unsmob_element (gh_car (elts));
+  SCM elts = me->get_grob_property ("elements");
+  Grob * b = unsmob_element (gh_car (elts));
   SCM glsym =ly_symbol2scm ("glyph");
-  SCM gl =b ->get_elt_property (glsym);
+  SCM gl =b ->get_grob_property (glsym);
   if (!gh_string_p (gl))
     {
       me->suicide ();
@@ -117,12 +117,12 @@ Span_bar::evaluate_glyph (Score_element*me)
     }
 
   gl = ly_str02scm (type.ch_C());
-  if (scm_equal_p (me->get_elt_property (glsym), gl) != SCM_BOOL_T)
-    me->set_elt_property (glsym, gl);
+  if (scm_equal_p (me->get_grob_property (glsym), gl) != SCM_BOOL_T)
+    me->set_grob_property (glsym, gl);
 }
 
 Interval
-Span_bar::get_spanned_interval (Score_element*me) 
+Span_bar::get_spanned_interval (Grob*me) 
 {
   return ly_scm2interval (Axis_group_interface::group_extent_callback (me->self_scm(), gh_int2scm (Y_AXIS))); 
 }
@@ -132,7 +132,7 @@ MAKE_SCHEME_CALLBACK(Span_bar,get_bar_size,1);
 SCM
 Span_bar::get_bar_size (SCM smob)
 {
-  Score_element* me =  unsmob_element (smob);
+  Grob* me =  unsmob_element (smob);
   Interval iv (get_spanned_interval (me));
   if (iv.empty_b ())
     {
@@ -146,7 +146,7 @@ Span_bar::get_bar_size (SCM smob)
 }
 
 void
-Span_bar::set_interface (Score_element *me)
+Span_bar::set_interface (Grob *me)
 {
   Bar::set_interface (me);
   
@@ -155,7 +155,7 @@ Span_bar::set_interface (Score_element *me)
 }
 
 bool
-Span_bar::has_interface (Score_element*m)
+Span_bar::has_interface (Grob*m)
 {
   return m && m->has_interface (ly_symbol2scm ("span-bar-interface"));
 }
