@@ -28,12 +28,12 @@ public:
   Span_dynamic_performer ();
 
 protected:
-  virtual bool do_try_music (Music*);
-  virtual void acknowledge_element (Audio_element_info);
-  virtual void process_acknowledged ();
-  virtual void do_process_music ();
-  virtual void do_pre_move_processing ();
-  virtual void do_post_move_processing ();
+  virtual bool try_music (Music*);
+  virtual void acknowledge_grob (Audio_element_info);
+  virtual void create_grobs ();
+  void deprecated_process_music ();
+  virtual void stop_translation_timestep ();
+  virtual void start_translation_timestep ();
 
 private:
   Audio_dynamic* audio_p_;
@@ -58,7 +58,7 @@ Span_dynamic_performer::Span_dynamic_performer ()
 }
 
 void
-Span_dynamic_performer::acknowledge_element (Audio_element_info i)
+Span_dynamic_performer::acknowledge_grob (Audio_element_info i)
 {
   if (Audio_dynamic * d = dynamic_cast <Audio_dynamic*> (i.elem_l_))
     {
@@ -67,7 +67,7 @@ Span_dynamic_performer::acknowledge_element (Audio_element_info i)
 }
 
 void
-Span_dynamic_performer::do_process_music ()
+Span_dynamic_performer::deprecated_process_music ()
 {
   if (span_start_req_l_ || span_req_l_drul_[START])
     {
@@ -109,8 +109,9 @@ Span_dynamic_performer::do_process_music ()
 }
 
 void
-Span_dynamic_performer::process_acknowledged ()
+Span_dynamic_performer::create_grobs ()
 {
+  deprecated_process_music ();
   if (span_req_l_drul_[STOP])
    { 
      finished_dynamic_tuple_arr_.top ().audio_l_->volume_ = last_volume_;
@@ -120,10 +121,13 @@ Span_dynamic_performer::process_acknowledged ()
     {
      dynamic_tuple_arr_[0].audio_l_->volume_ = last_volume_;
     }
+  span_start_req_l_ = 0;
+  span_req_l_drul_[START] = 0;
+  span_req_l_drul_[STOP] = 0;
 }
   
 void
-Span_dynamic_performer::do_pre_move_processing ()
+Span_dynamic_performer::stop_translation_timestep ()
 {
   if (finished_dynamic_tuple_arr_.size () > 1)
     {
@@ -169,14 +173,14 @@ Span_dynamic_performer::do_pre_move_processing ()
 }
 
 void
-Span_dynamic_performer::do_post_move_processing ()
+Span_dynamic_performer::start_translation_timestep ()
 {
   span_req_l_drul_[STOP] = 0;
   span_req_l_drul_[START] = 0;
 }
 
 bool
-Span_dynamic_performer::do_try_music (Music* r)
+Span_dynamic_performer::try_music (Music* r)
 {
   if (Span_req * s = dynamic_cast<Span_req*>(r))
     {
