@@ -7,21 +7,60 @@
   
  */
 
-#include "tie-performer.hh"
 #include "command-request.hh"
 #include "audio-item.hh"
 #include "musical-request.hh"
+#include "pqueue.hh"
+#include "performer.hh"
 
+struct CNote_melodic_tuple {
+  Melodic_req *req_l_ ;
+  Audio_note *note_l_;
+  Moment end_;
+  CNote_melodic_tuple ();
+  CNote_melodic_tuple (Audio_note*, Melodic_req*, Moment);
+  static int pitch_compare (CNote_melodic_tuple const &, CNote_melodic_tuple const &);
+  static int time_compare (CNote_melodic_tuple const &, CNote_melodic_tuple const &);  
+};
+
+inline int compare (CNote_melodic_tuple const &a, CNote_melodic_tuple const &b)
+{
+  return CNote_melodic_tuple::time_compare (a,b);
+}
+
+
+/**
+   Manufacture ties.  Acknowledge notes, and put them into a
+   priority queue. If we have a Tie_req, connect the notes that finish
+   just at this time, and note that start at this time.
+
+   TODO: should share code with Tie_engraver ?
+ */
+class Tie_performer : public Performer
+{
+public:
+  VIRTUAL_COPY_CONS(Translator);
+
+private:
+  bool done_;
+  PQueue<CNote_melodic_tuple> past_notes_pq_;
+  Tie_req *req_l_;
+  Array<CNote_melodic_tuple> now_notes_;
+  Array<CNote_melodic_tuple> stopped_notes_;
+  Link_array<Audio_tie> tie_p_arr_;
+  
+protected:
+  virtual void start_translation_timestep ();
+  virtual void stop_translation_timestep ();
+  virtual void acknowledge_grob (Audio_element_info);
+  virtual bool try_music (Music*);
+  virtual void create_grobs ();
+};
 
 ADD_THIS_TRANSLATOR (Tie_performer);
 
-Tie_performer::Tie_performer()
-{
-  req_l_ = 0;
-}
-
 bool
-Tie_performer::do_try_music (Music *m)
+Tie_performer::try_music (Music *m)
 {
   if (!req_l_)
     {
@@ -35,7 +74,7 @@ Tie_performer::do_try_music (Music *m)
 }
 
 void
-Tie_performer::acknowledge_element (Audio_element_info i)
+Tie_performer::acknowledge_grob (Audio_element_info i)
 {
   if (Audio_note *nh = dynamic_cast<Audio_note *> (i.elem_l_))
     {
@@ -47,9 +86,9 @@ Tie_performer::acknowledge_element (Audio_element_info i)
 }
 
 void
-Tie_performer::do_process_music ()
+Tie_performer::create_grobs ()
 {
-  if (req_l_)
+  if (req_l_ && ! done_)
     {
       Moment now = now_mom ();
       Link_array<Audio_note> nharr;
@@ -58,12 +97,10 @@ Tie_performer::do_process_music ()
       while (past_notes_pq_.size ()
 	     && past_notes_pq_.front ().end_ == now)
 	stopped_notes_.push (past_notes_pq_.get ());
+      done_ = true;
+      return;
     }
-}
 
-void
-Tie_performer::process_acknowledged ()
-{
   if (req_l_)
     {
       now_notes_.sort (CNote_melodic_tuple::pitch_compare);
@@ -108,12 +145,11 @@ Tie_performer::process_acknowledged ()
 	{
 	  req_l_->origin ()->warning (_("No ties were created!"));
 	}
-      
     }
 }
 
 void
-Tie_performer::do_pre_move_processing ()
+Tie_performer::stop_translation_timestep ()
 {
   for (int i=0; i < now_notes_.size (); i++)
     {
@@ -130,9 +166,10 @@ Tie_performer::do_pre_move_processing ()
 }
 
 void
-Tie_performer::do_post_move_processing ()
+Tie_performer::start_translation_timestep ()
 {
   req_l_ =0;
+  done_ = false;
   Moment now = now_mom ();
   while (past_notes_pq_.size () && past_notes_pq_.front ().end_ < now)
     past_notes_pq_.delmin ();
